#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
#
from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    DropdownChoice,
    MonitoringState,
    Integer,
)

from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)


def _parameter_valuespec_checkpoint_asg_chassis():
    return Dictionary(
        elements=[
            ('desired_chassis_active',
             DropdownChoice(
                 title=_('Desired active chassis'),
                 help=_('Select witch chassis should be active'),
                 sorted=True,
                 default_value='1',
                 choices=[
                     ('1', _('Chassis ID 1')),
                     ('2', _('Chassis ID 2')),
                 ],
             )),
            ('state_chassis_not_desired_active',
             MonitoringState(
                 default_value=1,
                 title=_('State if desired chassis not active'),
                 help=_('Monitoring state if the desired chassis not active'),
             )),
            ('state_chassis_number_changed',
             MonitoringState(
                 default_value=2,
                 title=_('State if number of chassis has changed'),
                 help=_('Monitoring state if number of chassis differs from discovery time'),
             )),
            ('state_chassis_not_active_standby',
             MonitoringState(
                 default_value=2,
                 title=_('State if chassis not active/standby'),
                 help=_('Monitoring state if the chassis not active or standby'),
             )),
            ('state_chassis_not_max_grade',
             MonitoringState(
                 default_value=2,
                 title=_('State if chassis is not optimal'),
                 help=_('Monitoring state if the chassis grade is less than max grade'),
             )),
            ('state_sgm_not_active',
             MonitoringState(
                 default_value=2,
                 title=_('State if SGM is not active'),
                 help=_('Monitoring state if the SGM state is not active'),
             )),
            ('state_sgms_number_changed',
             MonitoringState(
                 default_value=2,
                 title=_('State if number of SGMs has canged'),
                 help=_('Monitoring state if number of SGMs differs from discovery time'),
             )),
            ('discovery_chassis', Integer()),  # added by plugin discovery function
            ('discovery_sgms', Integer()),  # added by plugin discovery function
        ],
        hidden_keys=['discovery_chassis', 'discovery_sgms'],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name='checkpoint_asg_chassis',
        group=RulespecGroupCheckParametersNetworking,
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_checkpoint_asg_chassis,
        title=lambda: _('Check Point ASG Monitor'),
    ))
